%define afsvers 1.0.2

# Uncomment the particular line to build for 2.2 or 2.4 Kernels
%define kernvers 22
#define kernvers 24

# This is where to look for kernel-build includes files
%define kbase /usr/src/linux-

%ifarch i386 i486 i586
%define sysbase i386
%else
%define sysbase %{_arch}
%endif

%define sysname %{sysbase}_linux%{kernvers}

Summary: OpenAFS distributed filesystem
Name: openafs
Version: %{afsvers}
Release: %{kernvers}.1
Copyright: IPL
BuildRoot: /var/tmp/openafs-root
Source0: http://www.openafs.org/dl/openafs/${afsvers}/openafs-%{afsvers}-src.tar.gz
Source1: openafs-redhat.tar.gz
Packager: Derek Atkins <warlord@MIT.EDU>
Group: Networking/Filesystems
Requires: openafs-kernel

%description
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides common files shared across all the various
OpenAFS packages but are not necessarily tied to a client or server.

%package client
Requires: openafs-kernel openafs
Summary: OpenAFS Filesystem Client
Group: Networking/Filesystem

%description client
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides basic client support to mount and manipulate
AFS.

%package server
Requires: openafs-kernel openafs
Summary: OpenAFS Filesystem Server
Group: Networking/Filesystems

%description server
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides basic server support to host files in an AFS
Cell.

%package devel
Summary: OpenAFS Development Libraries and Headers
Group: Development/Filesystems

%description devel
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides static development libraries and headers needed
to compile AFS applications.  Note: AFS currently does not provide
shared libraries.

%package kernel
Summary: OpenAFS Kernel Module(s)
Group: Networking/Filesystems

%description kernel
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides precompiled AFS kernel modules for various
kernels.

%package kernel-source
Summary: OpenAFS Kernel Module source tree
Group: Networking/Filesystems

%description kernel-source
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides the source code to build your own AFS kernel
module.

%prep
%setup -q -n openafs-%{afsvers} -a 1

ln -s src/Makefile
mkdir %sysname %sysname/dest %sysname/obj
ln -s %sysname/dest
ln -s %sysname/obj
ln -s %sysname @sys
make links

###
### build
###
%build

if [ %{kernvers} = 22 ]; then
   kv='2\.2\.'
elif [ %{kernvers} = 24 ]; then
   kv='2\.4\.'
else
  echo "I don't know how to build %sysname"
  exit 1
fi

kvers=`ls -d %{kbase}* | sed 's^%{kbase}^^g' | grep $kv`
make SYS_NAME=%sysname LINUX_VERS="`echo $kvers`"
#make SYS_NAME=%sysname LINUX_VERS="2.2.14-5.0"

###
### install
###
%install

# Build install tree
mkdir -p $RPM_BUILD_ROOT/afs
mkdir -p $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT/etc/sysconfig
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/openafs
mkdir -p $RPM_BUILD_ROOT/lib/security
mkdir -p $RPM_BUILD_ROOT/usr/afs/logs
mkdir -p $RPM_BUILD_ROOT/usr/vice/etc
mkdir -p $RPM_BUILD_ROOT/usr/vice/cache
chmod 700 $RPM_BUILD_ROOT/usr/vice/cache

# Copy files from dest to the appropriate places in BuildRoot
tar cf - -C dest bin include lib | tar xf - -C $RPM_BUILD_ROOT/usr
tar cf - -C dest/etc . | tar xf - -C $RPM_BUILD_ROOT/usr/sbin
tar cf - -C dest/root.server/usr/afs bin | tar xf - -C $RPM_BUILD_ROOT/usr/afs
tar cf - -C dest/root.client/usr/vice/etc afsd modload | tar xf - -C $RPM_BUILD_ROOT/usr/vice/etc

# Copy root.client config files
install -m 755 dest/root.client/usr/vice/etc/afs.conf $RPM_BUILD_ROOT/etc/sysconfig/afs
install -m 755 dest/root.client/usr/vice/etc/afs.rc $RPM_BUILD_ROOT/etc/rc.d/init.d/afs

# Copy PAM modules
install -m 755 dest/lib/pam* $RPM_BUILD_ROOT/lib/security

# Populate /usr/vice/etc
tar cf - -C redhat/usr_vice_etc . | tar xf - -C $RPM_BUILD_ROOT/usr/vice/etc

#
# install kernel-source
#

# Install the kernel module source tree
mkdir -p $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}/src
tar cf - -C obj/libafs Makefile afs afsint rx | tar xf - -C $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}/src

# Copy Makefile.common, by hand (it's usually a symlink)
install -m 644 obj/libafs/Makefile.common $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}/src

# Next, copy the LICENSE, README, and top-level Makefile
install -m 644 src/LICENSE $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}/LICENSE.IBM
install -m 644 redhat/LICENSE.Sun $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}
install -m 644 redhat/README $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}
install -m 644 redhat/Makefile $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}

# Patch the Makefile
cat redhat/Makefile.libafs.patch | (cd $RPM_BUILD_ROOT/usr/src/openafs-kernel-%{afsvers}/src; patch)

#
# Install DOCUMENTATION
#

# Build the DOC directory
mkdir -p $RPM_BUILD_ROOT/usr/doc/openafs-%{afsvers}
install -m 644 src/LICENSE $RPM_BUILD_ROOT/usr/doc/openafs-%{afsvers}

###
### clean
###
%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###
%post
chkconfig --add afs

%post client
echo
echo The AFS cache is configured for 100 MB. Edit the 
echo /usr/vice/etc/cachinfo file to change this before
echo running AFS for the first time. You should also
echo set your home cell in /usr/vice/etc/ThisCell.
echo
echo Also, you may want to edit /etc/pam.d/login and 
echo possibly others there to get an AFS token on login.
echo Put the line:
echo 
echo    auth	   sufficient   /lib/security/pam_afs.so try_first_pass ignore_root
echo
echo before the one for pwdb.
echo

%post server
if [ -f /etc/sysconfig/afs ]; then
	srv=`grep ^AFS_SERVER /etc/sysconfig/afs | sed 's/^AFS_SERVER[\s]*=[\s]*//'`
	if [ $srv eq "on"]; then
		exit 0
	fi
fi

echo
echo Be sure to edit /etc/sysconfig/afs and turn AFS_SERVER on
echo

%preun
if [ $1 = 0 ] ; then
        /etc/rc.d/init.d/afs stop
        chkconfig --del afs
fi

###
### file lists
###
%files
%defattr(-,root,root)
%dir /usr/vice/etc/modload
%config /etc/sysconfig/afs
%doc /usr/doc/openafs-%{afsvers}
/etc/rc.d/init.d/afs
/usr/bin/bos
/usr/bin/fs
/usr/bin/klog
/usr/bin/klog.krb
/usr/bin/pagsh
/usr/bin/pts
/usr/bin/scout
/usr/bin/sys
/usr/bin/tokens
/usr/bin/tokens.krb
/usr/bin/udebug
/usr/bin/unlog
/usr/sbin/backup
/usr/sbin/butc
/usr/sbin/fstrace
/usr/sbin/kas
/usr/sbin/restorevol
/usr/sbin/vos

%files client
%defattr(-,root,root)
%dir /afs
%dir /usr/vice/cache
%config /usr/vice/etc/CellServDB
%config /usr/vice/etc/SuidCells
%config /usr/vice/etc/ThisCell
%config /usr/vice/etc/cacheinfo
/usr/bin/cmdebug
/usr/vice/etc/afsd
/lib/security/pam_afs.krb.so.1
/lib/security/pam_afs.so.1

%files server
%defattr(-,root,root)
%dir /usr/afs
%dir /usr/afs/bin
%dir /usr/afs/logs
/usr/afs/bin/bosserver
/usr/afs/bin/buserver
/usr/afs/bin/fileserver
# Should we support KAServer?
/usr/afs/bin/kaserver
/usr/afs/bin/kpwvalid
/usr/afs/bin/pt_util
/usr/afs/bin/ptserver
/usr/afs/bin/salvager
/usr/afs/bin/upclient
/usr/afs/bin/upserver
/usr/afs/bin/vlserver
/usr/afs/bin/volinfo
/usr/afs/bin/volserver
/usr/sbin/prdb_check
/usr/sbin/vldb_check
/usr/sbin/vldb_convert

%files devel
%defattr(-,root,root)
/usr/bin/rxgen
/usr/include/afs
/usr/include/rx
/usr/include/ubik.h
/usr/include/ubik_int.h
/usr/include/lock.h
/usr/include/lwp.h
/usr/include/preempt.h
/usr/include/timer.h
/usr/include/des.h
/usr/include/des_conf.h
/usr/include/des_odd.h
/usr/include/mit-cpyright.h
/usr/include/itc.h
/usr/include/potpourri.h
/usr/lib/afs
/usr/lib/librxkad.a
/usr/lib/libafsauthent.a
/usr/lib/libafsrpc.a
/usr/lib/libubik.a
/usr/lib/librxstat.a
/usr/lib/librx.a
/usr/lib/liblwp.a
/usr/lib/libdes.a

%files kernel
%defattr(-,root,root)
/usr/vice/etc/modload/libafs*.o

%files kernel-source
%defattr(-,root,root)
/usr/src/openafs-kernel-%{afsvers}/LICENSE.IBM
/usr/src/openafs-kernel-%{afsvers}/LICENSE.Sun
/usr/src/openafs-kernel-%{afsvers}/README
/usr/src/openafs-kernel-%{afsvers}/Makefile
/usr/src/openafs-kernel-%{afsvers}/src
